==> netjsonconfig-0.1-py2.py3-none-any.whl: netjsonconfig/schema.py <==
"""
NetJSON DeviceConfiguration JSON-Schema definition
this should be up to date with the official spec:

http://netjson.org/rfc.html#DeviceConfiguration-schema
"""

schema = {
    "$schema": "http://json-schema.org/draft-04/schema#",
    "id": "/",
    "type": "object",
    "additionalProperties": True,
    "required": [
        "type"
    ],
    "properties": {
        "type": {
            "id": "type",
            "type": "string",
            "default": "DeviceConfiguration",
            "pattern": "DeviceConfiguration"
        },
        "general": {
            "id": "general",
            "type": "object",
            "title": "General",
            "additionalProperties": True,
            "properties": {
                "hostname": {
                    "id": "hostname",
                    "type": "string"
                },
                "maintainer": {
                    "id": "maintainer",
                    "type": "string"
                },
                "description": {
                    "id": "description",
                    "type": "string"
                }
            }
        },
        "hardware": {
            "id": "hardware",
            "type": "object",
            "title": "Hardware",
            "additionalProperties": True,
            "properties": {
                "manufacturer": {
                    "id": "manufacturer",
                    "type": "string"
                },
                "model": {
                    "id": "model",
                    "type": "string"
                },
                "revision": {
                    "id": "revision",
                    "type": "integer"
                },
                "cpu": {
                    "id": "cpu",
                    "type": "string"
                }
            }
        },
        "operating_system": {
            "id": "operating_system",
            "type": "object",
            "title": "Operating System",
            "additionalProperties": True,
            "properties": {
                "name": {
                    "id": "name",
                    "type": "string"
                },
                "kernel": {
                    "id": "kernel",
                    "type": "string"
                },
                "version": {
                    "id": "version",
                    "type": "string"
                },
                "revision": {
                    "id": "revision",
                    "type": "string"
                },
                "description": {
                    "id": "description",
                    "type": "string"
                }
            }
        },
        "resources": {
            "id": "resources",
            "type": "object",
            "title": "Resources",
            "additionalProperties": True,
            "properties": {
                "memory": {
                    "id": "memory",
                    "type": "object",
                    "additionalProperties": True,
                    "properties": {
                        "total": {
                            "id": "total",
                            "type": "integer"
                        }
                    }
                },
                "swap": {
                    "id": "swap",
                    "type": "object",
                    "additionalProperties": True,
                    "properties": {
                        "total": {
                            "id": "total",
                            "type": "integer"
                        }
                    }
                },
                "cpu": {
                    "id": "cpu",
                    "type": "object",
                    "additionalProperties": True,
                    "properties": {
                        "frequency": {
                            "id": "frequency",
                            "type": "integer"
                        }
                    }
                },
                "flash": {
                    "id": "flash",
                    "type": "object",
                    "additionalProperties": True,
                    "properties": {
                        "total": {
                            "id": "total",
                            "type": "integer"
                        }
                    }
                },
                "storage": {
                    "id": "storage",
                    "type": "object",
                    "additionalProperties": True,
                    "properties": {
                        "total": {
                            "id": "total",
                            "type": "integer"
                        }
                    }
                }
            }
        },
        "radios": {
            "id": "radios",
            "type": "array",
            "title": "Radios",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "Radio",
                "additionalProperties": True,
                "required": [
                    "name",
                    "channel",
                    "channel_width",
                    "tx_power"
                ],
                "properties": {
                    "name": {
                        "id": "name",
                        "type": "string"
                    },
                    "phy": {
                        "id": "phy",
                        "type": "string"
                    },
                    "channel": {
                        "id": "channel",
                        "type": "integer"
                    },
                    "channel_width": {
                        "id": "channel_width",
                        "type": "integer"
                    },
                    "tx_power": {
                        "id": "tx_power",
                        "type": "integer"
                    },
                    "country": {
                        "id": "country",
                        "type": "string",
                        "minLength": 2,
                        "maxLength": 2
                    },
                    "disabled": {
                        "id": "disabled",
                        "type": "boolean",
                        "default": False
                    }
                }
            }
        },
        "interfaces": {
            "id": "interfaces",
            "type": "array",
            "title": "Interfaces",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "Interface",
                "additionalProperties": True,
                "required": [
                    "name"
                ],
                "properties": {
                    "type": {
                        "id": "type",
                        "type": "string",
                        "enum": [
                            "ethernet",
                            "wireless",
                            "bridge",
                            "virtual",
                            "loopback"
                        ]
                    },
                    "name": {
                        "id": "name",
                        "type": "string"
                    },
                    "mac": {
                        "id": "mac",
                        "type": "string"
                    },
                    "mtu": {
                        "id": "mtu",
                        "type": "integer",
                        "default": 1500
                    },
                    "txqueuelen": {
                        "id": "txqueuelen",
                        "type": "integer"
                    },
                    "autostart": {
                        "id": "autostart",
                        "type": "boolean",
                        "default": True
                    },
                    "addresses": {
                        "id": "addresses",
                        "type": "array",
                        "title": "Addresses",
                        "uniqueItems": True,
                        "additionalItems": True,
                        "items": {
                            "type": "object",
                            "title": "Address",
                            "additionalProperties": True,
                            "properties": {
                                "address": {
                                    "id": "address",
                                    "type": "string"
                                },
                                "mask": {
                                    "id": "mask",
                                    "type": "integer"
                                },
                                "gateway": {
                                    "id": "gateway",
                                    "type": "string"
                                },
                                "family": {
                                    "id": "family",
                                    "type": "string",
                                    "enum": [
                                        "ipv4",
                                        "ipv6"
                                    ]
                                },
                                "proto": {
                                    "id": "proto",
                                    "type": "string",
                                    "enum": [
                                        "static",
                                        "dhcp"
                                    ]
                                }
                            }
                        }
                    },
                    "bridge_members": {
                        "id": "bridge_members",
                        "type": "array",
                        "title": "Bridge Members",
                        "items": [
                            {
                                "type": "string"
                            }
                        ]
                    },
                    "wireless": {
                        "type": "array",
                        "title": "Wireless interfaces",
                        "uniqueItems": True,
                        "additionalItems": True,
                        "items": {
                            "type": "object",
                            "title": "Wireless Interface",
                            "additionalProperties": True,
                            "required": [
                                "radio",
                                "mode",
                                "ssid"
                            ],
                            "properties": {
                                "radio": {
                                    "id": "radio",
                                    "type": "string"
                                },
                                "mode": {
                                    "id": "mode",
                                    "type": "string",
                                    "enum": [
                                        "access_point",
                                        "station",
                                        "adhoc",
                                        "wds",
                                        "monitor",
                                        "802.11s"
                                    ]
                                },
                                "ssid": {
                                    "id": "ssid",
                                    "type": "string"
                                },
                                "bssid": {
                                    "id": "bssid",
                                    "type": "string"
                                },
                                "hidden": {
                                    "id": "bssid",
                                    "type": "boolean",
                                    "default": False
                                },
                                "ack_distance": {
                                    "id": "ack_distance",
                                    "type": "integer",
                                    "minimum": 1
                                },
                                "rts_threshold": {
                                    "id": "rts_threshold",
                                    "type": "integer",
                                    "minimum": 0,
                                    "maximum": 2346
                                },
                                "frag_threshold": {
                                    "id": "frag_threshold",
                                    "type": "integer",
                                    "minimum": 0,
                                    "maximum": 2346
                                },
                                "encryption": {
                                    "id": "encryption",
                                    "type": "object",
                                    "title": "Encryption",
                                    "required": [
                                        "enabled",
                                        "protocol",
                                        "key"
                                    ],
                                    "properties": {
                                        "enabled": {
                                            "id": "enabled",
                                            "type": "boolean"
                                        },
                                        "protocol": {
                                            "id": "protocol",
                                            "type": "string",
                                            "enum": [
                                                "wep_open",
                                                "wep_shared",
                                                "wpa_personal",
                                                "wpa2_personal",
                                                "wpa_personal_mixed",
                                                "wpa_enterprise",
                                                "wpa2_enterprise",
                                                "wpa_enterprise_mixed",
                                                "wps"
                                            ]
                                        },
                                        "ciphers": {
                                            "id": "ciphers",
                                            "type": "array"
                                        },
                                        "key": {
                                            "id": "key",
                                            "type": "string"
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }
        },
        "routes": {
            "id": "routes",
            "type": "array",
            "title": "Routes",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "Route",
                "additionalProperties": True,
                "required": [
                    "device",
                    "destination",
                    "next"
                ],
                "properties": {
                    "device": {
                        "id": "device",
                        "type": "string"
                    },
                    "next": {
                        "id": "next",
                        "type": "string"
                    },
                    "destination": {
                        "id": "destination",
                        "type": "string"
                    }
                }
            }
        },
        "dns_servers": {
            "id": "dns_servers",
            "title": "DNS Servers",
            "type": "array",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "string"
            }
        },
        "dns_search": {
            "id": "dns_search",
            "title": "DNS Search",
            "type": "array",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "string"
            }
        }
    }
}

==> netjsonconfig-0.2-py2.py3-none-any.whl: netjsonconfig/schema.py <==
"""
NetJSON DeviceConfiguration JSON-Schema definition
this should be up to date with the official spec:

http://netjson.org/rfc.html#DeviceConfiguration-schema
"""

schema = {
    "$schema": "http://json-schema.org/draft-04/schema#",
    "type": "object",
    "additionalProperties": True,
    "definitions": {
        "interface_settings": {
            "type": "object",
            "additionalProperties": True,
            "required": [
                "name",
                "type"
            ],
            "properties": {
                "name": {
                    "type": "string",
                    "maxLength": 15,
                    "pattern": "^[^\s]*$"
                },
                "mac": {
                    "type": "string"
                },
                "mtu": {
                    "type": "integer",
                    "default": 1500
                },
                "txqueuelen": {
                    "type": "integer"
                },
                "autostart": {
                    "type": "boolean",
                    "default": True
                },
                "disabled": {
                    "type": "boolean",
                    "default": False
                },
                "addresses": {
                    "type": "array",
                    "title": "Addresses",
                    "uniqueItems": True,
                    "additionalItems": True,
                    "items": {
                        "type": "object",
                        "title": "Address",
                        "additionalProperties": True,
                        "properties": {
                            "address": {
                                "type": "string"
                            },
                            "mask": {
                                "type": "integer"
                            },
                            "gateway": {
                                "type": "string"
                            },
                            "family": {
                                "type": "string",
                                "enum": [
                                    "ipv4",
                                    "ipv6"
                                ]
                            },
                            "proto": {
                                "type": "string",
                                "enum": [
                                    "static",
                                    "dhcp"
                                ]
                            }
                        }
                    }
                }
            }
        },
        "network_interface": {
            "title": "Network interface",
            "allOf": [
                {
                    "properties": {
                        "type": {
                            "type": "string",
                            "enum": [
                                "ethernet",
                                "virtual",
                                "loopback",
                                "other"
                            ]
                        }
                    }
                },
                {"$ref": "#/definitions/interface_settings"}
            ]
        },
        "wireless_interface": {
            "title": "Wireless interface",
            "allOf": [
                {
                    "properties": {
                        "type": {
                            "type": "string",
                            "enum": ["wireless"],
                            "default": "wireless"
                        }
                    }
                },
                {"$ref": "#/definitions/interface_settings"},
                {
                    "properties": {
                        "wireless": {
                            "type": "object",
                            "title": "Wireless Interface",
                            "additionalProperties": True,
                            "required": [
                                "radio",
                                "mode",
                                "ssid"
                            ],
                            "properties": {
                                "radio": {
                                    "type": "string"
                                },
                                "mode": {
                                    "type": "string",
                                    "enum": [
                                        "access_point",
                                        "station",
                                        "adhoc",
                                        "wds",
                                        "monitor",
                                        "802.11s"
                                    ]
                                },
                                "ssid": {
                                    "type": "string",
                                    "maxLength": 32
                                },
                                "bssid": {
                                    "type": "string"
                                },
                                "hidden": {
                                    "type": "boolean",
                                    "default": False
                                },
                                "ack_distance": {
                                    "type": "integer",
                                    "minimum": 1
                                },
                                "rts_threshold": {
                                    "type": "integer",
                                    "minimum": 0,
                                    "maximum": 2346
                                },
                                "frag_threshold": {
                                    "type": "integer",
                                    "minimum": 0,
                                    "maximum": 2346
                                },
                                "encryption": {
                                    "type": "object",
                                    "title": "Encryption",
                                    "required": [
                                        "protocol",
                                        "key"
                                    ],
                                    "properties": {
                                        "protocol": {
                                            "type": "string",
                                            "enum": [
                                                "wep_open",
                                                "wep_shared",
                                                "wpa_personal",
                                                "wpa2_personal",
                                                "wpa_personal_mixed",
                                                "wpa_enterprise",
                                                "wpa2_enterprise",
                                                "wpa_enterprise_mixed",
                                                "wps"
                                            ]
                                        },
                                        "ciphers": {
                                            "type": "array"
                                        },
                                        "key": {
                                            "type": "string"
                                        },
                                        "disabled": {
                                            "type": "boolean",
                                            "default": False
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            ]
        },
        "bridge_interface": {
            "title": "Bridge interface",
            "required": [
                "bridge_members"
            ],
            "allOf": [
                {
                    "properties": {
                        "type": {
                            "type": "string",
                            "enum": ["bridge"]
                        }
                    }
                },
                {"$ref": "#/definitions/interface_settings"},
                {
                    "properties": {
                        "bridge_members": {
                            "type": "array",
                            "title": "Bridge Members",
                            "items": {
                                "type": "string"
                            }
                        }
                    }
                }
            ]
        }
    },
    "required": [
        "type"
    ],
    "properties": {
        "type": {
            "type": "string",
            "enum": ["DeviceConfiguration"]
        },
        "general": {
            "type": "object",
            "title": "General",
            "additionalProperties": True,
            "properties": {
                "hostname": {
                    "type": "string"
                },
                "maintainer": {
                    "type": "string"
                },
                "description": {
                    "type": "string"
                }
            }
        },
        "hardware": {
            "type": "object",
            "title": "Hardware",
            "additionalProperties": True,
            "properties": {
                "manufacturer": {
                    "type": "string"
                },
                "model": {
                    "type": "string"
                },
                "revision": {
                    "type": "integer"
                },
                "cpu": {
                    "type": "string"
                }
            }
        },
        "operating_system": {
            "type": "object",
            "title": "Operating System",
            "additionalProperties": True,
            "properties": {
                "name": {
                    "type": "string"
                },
                "kernel": {
                    "type": "string"
                },
                "version": {
                    "type": "string"
                },
                "revision": {
                    "type": "string"
                },
                "description": {
                    "type": "string"
                }
            }
        },
        "radios": {
            "type": "array",
            "title": "Radios",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "Radio",
                "additionalProperties": True,
                "required": [
                    "name",
                    "channel",
                    "channel_width",
                    "tx_power"
                ],
                "properties": {
                    "name": {
                        "type": "string"
                    },
                    "phy": {
                        "type": "string"
                    },
                    "channel": {
                        "type": "integer"
                    },
                    "channel_width": {
                        "type": "integer"
                    },
                    "tx_power": {
                        "type": "integer"
                    },
                    "country": {
                        "type": "string",
                        "minLength": 2,
                        "maxLength": 2
                    },
                    "disabled": {
                        "type": "boolean",
                        "default": False
                    }
                }
            }
        },
        "interfaces": {
            "type": "array",
            "title": "Interfaces",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "oneOf": [
                    {"$ref": "#/definitions/network_interface"},
                    {"$ref": "#/definitions/wireless_interface"},
                    {"$ref": "#/definitions/bridge_interface"}
                ]
            }
        },
        "routes": {
            "type": "array",
            "title": "Routes",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "object",
                "title": "Route",
                "additionalProperties": True,
                "required": [
                    "device",
                    "destination",
                    "next"
                ],
                "properties": {
                    "device": {
                        "type": "string"
                    },
                    "next": {
                        "type": "string"
                    },
                    "destination": {
                        "type": "string"
                    }
                }
            }
        },
        "dns_servers": {
            "title": "DNS Servers",
            "type": "array",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "string"
            }
        },
        "dns_search": {
            "title": "DNS Search",
            "type": "array",
            "uniqueItems": True,
            "additionalItems": True,
            "items": {
                "type": "string"
            }
        }
    }
}
